a1708067edcd7dbca14b244587c416afaf041114
jcasper
  Mon Apr 10 16:47:31 2017 -0700
DAS server can now contact a bottleneck server to moderate usage, refs #19193

diff --git src/hg/inc/botDelay.h src/hg/inc/botDelay.h
index c0c6fc2..c8412bc 100644
--- src/hg/inc/botDelay.h
+++ src/hg/inc/botDelay.h
@@ -17,17 +17,21 @@
 /* Print out message saying why you are stalled. */
 
 void hgBotDelay();
 /* High level bot delay call - for use with regular webpage output */ 
 
 void hgBotDelayFrac(double fraction);
 /* Like hgBotDelay, but imposes a fraction of the standard access penalty */ 
 
 void hgBotDelayNoWarn();
 /* High level bot delay call without warning - for use with non-webpage output */
 
 void hgBotDelayNoWarnFrac(double fraction);
 /* Like hgBotDelayNoWarn, but imposes a fraction of the standard access penalty */
 
 int hgBotDelayTime();
-/* Get suggested delay time from cgi. */
+/* Get suggested delay time from cgi using the standard penalty. */
+
+int hgBotDelayTimeFrac(double fraction);
+/* Get suggested delay time from cgi using the specified fraction of the standard penalty. */
+